@@ -399,6 +399,7 @@ extern void term_styled_ostream_flush (term_styled_ostream_t first_arg, ostream_
 extern void term_styled_ostream_free (term_styled_ostream_t first_arg);
 extern void term_styled_ostream_begin_use_class (term_styled_ostream_t first_arg, const char *classname);
 extern void term_styled_ostream_end_use_class (term_styled_ostream_t first_arg, const char *classname);
+extern void term_styled_ostream_flush_to_current_style (term_styled_ostream_t first_arg);
 #ifdef __cplusplus
 }
 #endif
@@ -438,6 +439,7 @@ extern void html_styled_ostream_flush (html_styled_ostream_t first_arg, ostream_
 extern void html_styled_ostream_free (html_styled_ostream_t first_arg);
 extern void html_styled_ostream_begin_use_class (html_styled_ostream_t first_arg, const char *classname);
 extern void html_styled_ostream_end_use_class (html_styled_ostream_t first_arg, const char *classname);
+extern void html_styled_ostream_flush_to_current_style (html_styled_ostream_t first_arg);
 #ifdef __cplusplus
 }
 #endif
@@ -530,6 +532,26 @@ extern void libtextstyle_set_failure_exit_code (int exit_code);
 }
 #endif
 
+/* ----------------------- Exported gnulib overrides ----------------------- */
+
+#if defined _WIN32 && ! defined __CYGWIN__
+
+# include <io.h>
+
+# ifdef __cplusplus
+extern "C" {
+# endif
+
+extern int libtextstyle_isatty (int fd);
+# undef isatty
+# define isatty libtextstyle_isatty
+
+# ifdef __cplusplus
+}
+# endif
+
+#endif
+
 /* ------------------------------------------------------------------------- */
 
 #endif /* _TEXTSTYLE_H */
